"""Main REST API router.

⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
"""

from __future__ import annotations

from fastapi import APIRouter

{% for snake_name in model_names %}
from .{{ snake_name }} import router as {{ snake_name }}_router
{% endfor %}
{% if auth_enabled %}
from .auth import router as auth_router
{% endif %}

router = APIRouter()

{% for snake_name in model_names %}
router.include_router({{ snake_name }}_router)
{% endfor %}
{% if auth_enabled %}
router.include_router(auth_router)
{% endif %}

__all__ = ["router"]
