"""Prism specification for {{ project_name }}.

Define your models here and run `prism generate` to create the full stack.
"""

from prism import (
    StackSpec,
    ModelSpec,
    FieldSpec,
    FieldType,
    FilterOperator,
)

spec = StackSpec(
    name="{{ project_name_snake }}",
    version="1.0.0",
    description="{{ description }}",
    models=[
        # Define your models here
        # Example:
        # ModelSpec(
        #     name="Customer",
        #     description="Customer entity",
        #     fields=[
        #         FieldSpec(name="name", type=FieldType.STRING, max_length=255, required=True),
        #         FieldSpec(name="email", type=FieldType.STRING, unique=True, required=True),
        #         FieldSpec(
        #             name="status",
        #             type=FieldType.ENUM,
        #             enum_values=["active", "inactive", "prospect"],
        #             default="prospect",
        #         ),
        #     ],
        # ),
    ],
)
