# {{ project_name }}

{{ description }}

## Quick Start

```bash
# Install dependencies
uv sync

# Generate code from spec
prism generate

# Run the API
uvicorn {{ project_name_snake }}.main:app --reload
```

## API Documentation

- OpenAPI docs: http://localhost:8000/docs
- ReDoc: http://localhost:8000/redoc
