/**
 * Detail view component for {{ model_name }}.
 *
 * ✅ YOUR CODE - Safe to modify, will not be overwritten.
 * This file was generated once by Prism and is yours to customize.
 */

import React from 'react';
import { {{ model_name }}DetailBase, type {{ model_name }}DetailBaseProps } from '../_generated/{{ model_name }}DetailBase';

interface {{ model_name }}DetailProps extends {{ model_name }}DetailBaseProps {
  // Add your custom props here
}

/**
 * {{ model_name }} detail view component.
 *
 * Customize this component to add:
 * - Related data sections
 * - Custom formatting
 * - Actions
 */
export function {{ model_name }}Detail(props: {{ model_name }}DetailProps): JSX.Element {
  return (
    <div className="{{ kebab_name }}-detail-container">
      <{{ model_name }}DetailBase {...props} />
      {/* Add related data, custom sections here */}
    </div>
  );
}

export default {{ model_name }}Detail;
