"""Custom GraphQL scalars.

⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
"""


import strawberry
from decimal import Decimal


# Re-export built-in scalars
JSON = strawberry.scalars.JSON


__all__ = ["JSON"]
