# API Reference

This section contains the API reference for {{ project_name }}.

## Modules

### Core Module

The core module provides the main functionality.

```python
from {{ project_name }} import core
```

### Utils Module

Utility functions and helpers.

```python
from {{ project_name }} import utils
```

## Classes

Documentation for classes will be generated automatically if mkdocstrings is enabled.

## Functions

Documentation for functions will be generated automatically if mkdocstrings is enabled.
