/**
 * GraphQL subscriptions for {{ model_name }}.
 *
 * ⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
 */

import { graphql } from '../gql';

/** Subscribe to {{ model_name }} creation events */
export const {{ model_name }}CreatedSubscription = graphql(`
  subscription {{ model_name }}Created {
    {{ camel_name }}Created {
      id
{{ fields_indent_6 }}
    }
  }
`);

/** Subscribe to {{ model_name }} update events */
export const {{ model_name }}UpdatedSubscription = graphql(`
  subscription {{ model_name }}Updated($id: Int) {
    {{ camel_name }}Updated(id: $id) {
      id
{{ fields_indent_6 }}
    }
  }
`);

/** Subscribe to {{ model_name }} deletion events */
export const {{ model_name }}DeletedSubscription = graphql(`
  subscription {{ model_name }}Deleted {
    {{ camel_name }}Deleted
  }
`);
