version: 2
updates:
  # Python dependencies
  - package-ecosystem: "pip"
    directory: "/"
    schedule:
      interval: "weekly"
    open-pull-requests-limit: 5
    {% if github_username %}
    reviewers:
      - "{{ github_username }}"
    {% endif %}

  {% if include_frontend %}
  # Frontend dependencies
  - package-ecosystem: "npm"
    directory: "/frontend"
    schedule:
      interval: "weekly"
    open-pull-requests-limit: 5
    {% if github_username %}
    reviewers:
      - "{{ github_username }}"
    {% endif %}
  {% endif %}

  # GitHub Actions
  - package-ecosystem: "github-actions"
    directory: "/"
    schedule:
      interval: "weekly"
