# Staging Environment Configuration for {{ project_name }}
# Generated by Prism
#
# Usage: terraform plan -var-file=staging.tfvars

# Deploy staging only
deploy_staging    = true
deploy_production = false

# Server configuration
staging_server_type = "{{ hetzner.staging_server_type.value }}"
staging_volume_size = {{ hetzner.staging_volume_size }}

# Location
location = "{{ hetzner.location.value }}"
