/**
 * Custom Design Token Overrides
 *
 * YOUR CODE - Safe to modify, will not be overwritten by Prism.
 *
 * Override any design tokens from design-tokens.css here.
 * This file is imported after design-tokens.css, so your values take precedence.
 *
 * Example overrides:
 *
 * :root {
 *   --color-primary: 37 99 235;
 *   --color-accent: 168 85 247;
 *   --radius-button: 9999px;
 * }
 *
 * [data-theme="dark"] {
 *   --color-primary: 96 165 250;
 * }
 */

/* Add your custom token overrides below */
