/**
 * GraphQL mutations for {{ model_name }}.
 *
 * ⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
 */

import { graphql } from '../gql';

{% if create_mutation %}
/** Create a new {{ model_name }} */
export const Create{{ model_name }}Mutation = graphql(`
  mutation Create{{ model_name }}($input: {{ model_name }}Input!) {
    create{{ model_name }}(input: $input) {
      id
{{ fields_indent_6 }}
    }
  }
`);

{% endif %}
{% if update_mutation %}
/** Update an existing {{ model_name }} */
export const Update{{ model_name }}Mutation = graphql(`
  mutation Update{{ model_name }}($id: Int!, $input: {{ model_name }}UpdateInput!) {
    update{{ model_name }}(id: $id, input: $input) {
      id
{{ fields_indent_6 }}
    }
  }
`);

{% endif %}
{% if delete_mutation %}
/** Delete a {{ model_name }} */
export const Delete{{ model_name }}Mutation = graphql(`
  mutation Delete{{ model_name }}($id: Int!) {
    delete{{ model_name }}(id: $id)
  }
`);
{% endif %}
