# Volume Module Outputs
# Generated by Prism

output "volume_id" {
  description = "Volume ID"
  value       = hcloud_volume.main.id
}

output "volume_size" {
  description = "Volume size in GB"
  value       = hcloud_volume.main.size
}

output "linux_device" {
  description = "Linux device path"
  value       = hcloud_volume.main.linux_device
}
