# Volume Module Variables
# Generated by Prism

variable "name" {
  description = "Volume name"
  type        = string
}

variable "size" {
  description = "Volume size in GB"
  type        = number
}

variable "location" {
  description = "Hetzner datacenter location"
  type        = string
}

variable "server_id" {
  description = "Server ID to attach volume to"
  type        = string
}

variable "labels" {
  description = "Labels to apply to volume"
  type        = map(string)
  default     = {}
}
