# Production Environment Configuration for {{ project_name }}
# Generated by Prism
#
# Usage: terraform plan -var-file=production.tfvars

# Deploy production (optionally keep staging running)
deploy_staging    = false
deploy_production = true

# Server configuration
production_server_type = "{{ hetzner.production_server_type.value }}"
production_volume_size = {{ hetzner.production_volume_size }}
production_floating_ip = {{ hetzner.production_floating_ip | lower }}

# Location
location = "{{ hetzner.location.value }}"
