/**
 * Table component for {{ model_name }}.
 *
 * ✅ YOUR CODE - Safe to modify, will not be overwritten.
 * This file was generated once by Prism and is yours to customize.
 */

import React from 'react';
import { {{ model_name }}TableBase, type {{ model_name }}TableBaseProps } from '../_generated/{{ model_name }}TableBase';

interface {{ model_name }}TableProps extends {{ model_name }}TableBaseProps {
  // Add your custom props here
}

/**
 * {{ model_name }} table component.
 *
 * Customize this component to add:
 * - Custom column rendering
 * - Additional columns
 * - Toolbar actions
 * - Filters
 */
export function {{ model_name }}Table(props: {{ model_name }}TableProps): JSX.Element {
  return (
    <div className="{{ kebab_name }}-table-container">
      {/* Add custom toolbar here */}
      <{{ model_name }}TableBase {...props} />
      {/* Add custom footer here */}
    </div>
  );
}

export default {{ model_name }}Table;
