"""Authentication module for {{ project_name }}.

AUTO-GENERATED BY PRISM - DO NOT EDIT
"""

from {{ project_name }}.auth.api_key_service import (
    APIKeyError,
    APIKeyService,
    api_key_service,
)

__all__ = [
    "APIKeyError",
    "APIKeyService",
    "api_key_service",
]
