/**
 * Application entry point with urql Provider.
 *
 * ⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
 * This file is regenerated on every `prism generate`.
 */

import React from 'react';
import ReactDOM from 'react-dom/client';
import { Provider } from 'urql';
import { client } from './graphql/client';
import App from './App';
import './index.css';{% if auth_enabled %}
import { AuthProvider } from './contexts/AuthContext';{% endif %}

ReactDOM.createRoot(document.getElementById('root')!).render(
  <React.StrictMode>
    <Provider value={client}>{% if auth_enabled %}
    <AuthProvider>{% endif %}
      <App />{% if auth_enabled %}
    </AuthProvider>{% endif %}
    </Provider>
  </React.StrictMode>
);
