/**
 * Prism Widget System.
 *
 * ⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
 */

// Types
export type {
  FieldType,
  WidgetBaseProps,
  Widget,
  WidgetKey,
  FieldSpec,
  ModelSpec,
} from './types';

// Registry
export { WidgetRegistry, widgetRegistry } from './registry';

// Context
export { WidgetProvider, useWidgetRegistry, useWidget } from './context';

// Default widgets
export { DEFAULT_WIDGETS, UI_WIDGET_MAP } from './defaults';

// Components
export * from './components';
